@@ -36,11 +36,32 @@ class FrozenEnviron(NamespaceWalker, clu.abstract.ReprWrapper,
                                      clu.abstract.Cloneable):
     
     """ A concrete immutable – or frozen – KeyMap class wrapping a
-        frozen copy of an environment-variable dictionary.
+        frozen copy of an environment-variable dictionary. Like
+        e.g., for an appname of “yodogg” and a namespace value of
+        “iheard”, the environment variable prefix would work out
+        such that a variable with a key value of “youlike” would
+        look like this:
+            
+            YODOGG_IHEARD_YOULIKE
+                         
+            ^^^^^^ ^^^^^^ ^^^^^^^
+               |      |      |
+               |      |      +––––– mapping key (uppercased)
+               |      +–––––––––––– namespaces (uppercased, one value)
+               +––––––––––––––––––– app name (uppercased)
+        
+        … This namespaced key can be accessed from an instance
+        of FrozenEnviron as “yodogg:iheard:youlike”.
     """
     
     __slots__ = ('environment', 'appname')
     
+    @classmethod
+    def from_dict(cls, instance_dict):
+        """ Used by `clu.config.codecs` to deserialize keymaps """
+        return cls(environment=instance_dict['environment'],
+                       appname=instance_dict['appname'])
+    
     def __init__(self, environment=None, appname=None, **updates):
         """ Initialize a FrozenKeyMap instance wrapping an environment-variable
             dictionary from a target dictionary, with a supplied appname.
@@ -98,6 +119,11 @@ class FrozenEnviron(NamespaceWalker, clu.abstract.ReprWrapper,
         out = type(self)(appname=self.appname)
         out.environment = copier(self.environment)
         return out
+    
+    def to_dict(self):
+        """ Used by `clu.config.codecs` to serialize the keymap """
+        return { 'environment'  : copy.deepcopy(self.environment),
+                 'appname'      : self.appname }
 
 @export
 class Environ(FrozenEnviron, KeyMap, contextlib.AbstractContextManager):
@@ -152,6 +178,11 @@ class Environ(FrozenEnviron, KeyMap, contextlib.AbstractContextManager):
             self.environment.update(self.stash or {})
         self.stash = None
         return exc_type is None
+    
+    def to_dict(self):
+        """ Used by `clu.config.codecs` to serialize the keymap """
+        return { 'environment'  : None, # reconstitution uses os.environ
+                 'appname'      : self.appname }
 
 # Assign the modules’ `__all__` and `__dir__` using the exporter:
 __all__, __dir__ = exporter.all_and_dir()
