@@ -9,8 +9,8 @@ import sys
 abstract = abc.abstractmethod
 
 from clu.constants.enums import System, SYSTEM
-# from clu.config.defg import FrozenKeyMap
-from clu.config.abc import NamespacedMutableMapping
+# from clu.config.abc import FrozenKeyMap
+from clu.config.base import NamespacedMutableMapping
 from clu.fs.appdirectories import AppDirs
 from clu.fs.filesystem import TemporaryName, Directory
 from clu.fs.misc import extension, filesize
