@@ -97,6 +97,10 @@ class FrozenFlat(FrozenKeyMap, clu.abstract.ReprWrapper,
     def clone(self, deep=False, memo=None):
         copier = deep and copy.deepcopy or copy.copy
         return type(self)(dictionary=copier(self.dictionary))
+    
+    def to_dict(self):
+        """ Used by `clu.config.codecs` to serialize the keymap """
+        return copy.deepcopy(self.dictionary)
 
 @export
 class Flat(FrozenFlat, KeyMap):
@@ -188,6 +192,10 @@ class FrozenNested(NamespaceWalker, clu.abstract.ReprWrapper,
         copier = deep and copy.deepcopy or copy.copy
         return type(self)(tree=copier(self.tree))
     
+    def to_dict(self):
+        """ Used by `clu.config.codecs` to serialize the keymap """
+        return copy.deepcopy(self.tree)
+    
     def __contains__(self, nskey):
         key, namespaces = unpack_ns(nskey)
         if not namespaces:
