@@ -192,6 +192,8 @@ faintly you came tapping, tapping at my chamber door?
 """
 
 # Python version figlet banners – using the figlet “Colossal” typeface:
+# $ echo "python3.11" | figlet -w 120 -k -f colossal | pbcopy
+
 banners = {}
 
 banners['python3.x'] = """
@@ -209,6 +211,51 @@ banners['python3.x'] = """
                                                                              
 """
 
+banners['python3.11'] = """
+                  888    888                         .d8888b.       d888    d888   
+                  888    888                        d88P  Y88b     d8888   d8888   
+                  888    888                             .d88P       888     888   
+88888b.  888  888 888888 88888b.   .d88b.  88888b.      8888"        888     888   
+888 "88b 888  888 888    888 "88b d88""88b 888 "88b      "Y8b.       888     888   
+888  888 888  888 888    888  888 888  888 888  888 888    888       888     888   
+888 d88P Y88b 888 Y88b.  888  888 Y88..88P 888  888 Y88b  d88P d8b   888     888   
+88888P"   "Y88888  "Y888 888  888  "Y88P"  888  888  "Y8888P"  Y8P 8888888 8888888 
+888           888                                                                  
+888      Y8b d88P                                                                  
+888       "Y88P"                                                                   
+                                                                              
+"""
+
+banners['python3.10'] = """
+                  888    888                         .d8888b.       d888    .d8888b.  
+                  888    888                        d88P  Y88b     d8888   d88P  Y88b 
+                  888    888                             .d88P       888   888    888 
+88888b.  888  888 888888 88888b.   .d88b.  88888b.      8888"        888   888    888 
+888 "88b 888  888 888    888 "88b d88""88b 888 "88b      "Y8b.       888   888    888 
+888  888 888  888 888    888  888 888  888 888  888 888    888       888   888    888 
+888 d88P Y88b 888 Y88b.  888  888 Y88..88P 888  888 Y88b  d88P d8b   888   Y88b  d88P 
+88888P"   "Y88888  "Y888 888  888  "Y88P"  888  888  "Y8888P"  Y8P 8888888  "Y8888P"  
+888           888                                                                     
+888      Y8b d88P                                                                     
+888       "Y88P"                                                                      
+                                                                              
+"""
+
+banners['python3.9'] = """
+                  888    888                         .d8888b.       .d8888b.  
+                  888    888                        d88P  Y88b     d88P  Y88b 
+                  888    888                             .d88P     888    888 
+88888b.  888  888 888888 88888b.   .d88b.  88888b.      8888"      Y88b. d888 
+888 "88b 888  888 888    888 "88b d88""88b 888 "88b      "Y8b.      "Y888P888 
+888  888 888  888 888    888  888 888  888 888  888 888    888            888 
+888 d88P Y88b 888 Y88b.  888  888 Y88..88P 888  888 Y88b  d88P d8b Y88b  d88P 
+88888P"   "Y88888  "Y888 888  888  "Y88P"  888  888  "Y8888P"  Y8P  "Y8888P"  
+888           888                                                             
+888      Y8b d88P                                                             
+888       "Y88P"                                                              
+                                                                              
+"""
+
 banners['python3.8'] = """
                   888    888                         .d8888b.       .d8888b.  
                   888    888                        d88P  Y88b     d88P  Y88b 
