@@ -22,21 +22,29 @@ iterchain = itertools.chain.from_iterable
 
 from clu.constants.consts import (λ, φ, # type: ignore
                                   APPNAME, BASEPATH, BUILTINS,
-                                  EXPORTER_NAME, QUALIFIER,
+                                  EXPORTER_NAME, QUALIFIER, ROOT_PATH,
                                   NoDefault, pytuple)
 from clu.constants.exceptions import BadDotpathWarning, ExportError, ExportWarning
 
 # Q.v. `search_by_id(…)` function sub.
 cache = lambda function: lru_cache(maxsize=128, typed=False)(function)
 
+# Not what you are looking for
+NotYourThing = object()
+# NotYourID = id(NotYourThing)
+
 def itermodule(module):
     """ Get an iterable of `(name, thing)` tuples for all things
         contained in a given module (although it’ll probably work
         for classes and instances too – anything `dir()`-able.)
     """
+    # the `getattr(…)` call below uses a default of `NotYourThing`
+    # to supress weird bugs that can arise when iterating through
+    # the contents of third-party modules that do “clever” things
+    # when their module code executes or whatever.
     keys = tuple(key for key in dir(module) \
                       if key not in BUILTINS)
-    values = (getattr(module, key) for key in keys)
+    values = (getattr(module, key, NotYourThing) for key in keys)
     yield from zip(keys, values)
 
 def moduleids(module):
@@ -53,9 +61,13 @@ def itermoduleids(module):
         tuples for all things comntained in a given module – q.v.
         `itermodule(…)` implementation supra.
     """
+    # the `getattr(…)` call below uses a default value of the id
+    # of `NotYourThing` to supress weird bugs that can arise when
+    # iterating through the contents of third-party modules that
+    # do “clever” things when their module code executes or whatever.
     keys = tuple(key for key in dir(module) \
                       if key not in BUILTINS)
-    ids = (id(getattr(module, key)) for key in keys)
+    ids = (id(getattr(module, key, NotYourThing)) for key in keys)
     yield from zip(keys, ids)
 
 # This goes against all logic and reason, but it fucking seems
@@ -226,9 +238,6 @@ replaceable_endings  = tuple(f"{pre}{suf}" \
                                                   ending_suffixes))
 replaceable_endings += ending_suffixes
 
-# Derive the filesystem’s root path representation:
-root_path = Path(BASEPATH).absolute().root
-
 def path_to_dotpath(path, relative_to=None):
     """ Convert a file path (e.g. “/yo/dogg/iheard/youlike.py”)
         to a dotpath (á la “yo.dogg.iheard.youlike”) in what I
@@ -245,7 +254,7 @@ def path_to_dotpath(path, relative_to=None):
     # Relativize the path to either the “relative_to” arg
     # …or – if that’s not a thing – the filesystem root,
     # and replace path separators with dots:
-    relpath = os.path.relpath(path, start=relative_to or root_path)
+    relpath = os.path.relpath(path, start=relative_to or ROOT_PATH)
     dotpath = relpath.replace(os.path.sep, QUALIFIER)
     
     # Trim off any remaining “.py” suffixes,
@@ -874,7 +883,7 @@ def test():
         """ Print all locals and globals for the module """
         everything()
     
-    @inline
+    @inline.runif(not consts.TEXTMATE)
     def test_one():
         """ Sanity-check “thismodule()” """
         assert thismodule() == 'clu.exporting'
