@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
-from distutils.spawn import find_executable
 from functools import lru_cache, wraps
 
 cache = lambda function: lru_cache(maxsize=128, typed=True)(function)
@@ -14,7 +13,7 @@ import shutil
 import sys, re, os
 import zipfile
 
-from clu.constants.consts import ENCODING, PATH, SCRIPT_PATH
+from clu.constants.consts import ENCODING, PATH, ROOT_PATH, SCRIPT_PATH
 from clu.constants.exceptions import ExecutionError, FilesystemError
 from clu.predicates import attr, allattrs, isexpandable, anyof
 from clu.sanitizer import utf8_encode
@@ -23,6 +22,7 @@ from clu.fs.abc import BaseFSName, TemporaryFileWrapper
 from clu.fs.misc import differentfile, filesize, gethomedir, masked_permissions
 from clu.fs.misc import re_matcher, re_searcher, suffix_searcher, re_excluder
 from clu.fs.misc import swapext, u8str, extension, modeflags, temporary
+from clu.fs.misc import grouped
 from clu.exporting import Exporter, path_to_dotpath
 
 exporter = Exporter(path=__file__)
@@ -63,23 +63,11 @@ def script_path():
     """ Return the path to the embedded scripts directory. """
     return SCRIPT_PATH
 
-@export
-def which(binary_name, pathvar=None):
-    """ Deduces the path corresponding to an executable name,
-        as per the UNIX command `which`. Optionally takes an
-        override for the $PATH environment variable.
-        Always returns a string - an empty one for those
-        executables that cannot be found.
-    """
-    return find_executable(binary_name, pathvar or which.pathvar) or ""
-
-which.pathvar = PATH
-
 @export
 def back_tick(command,  as_str=True,
                        ret_err=False,
                      raise_err=None, **kwargs):
-    f""" Run command `command`, returning stdout – or (stdout, stderr) if `ret_err`.
+    """ Run command `command`, returning stdout – or (stdout, stderr) if `ret_err`.
         
         Parameters
         ----------
@@ -90,8 +78,8 @@ def back_tick(command,  as_str=True,
         as_str : bool, optional
             Whether or not the values returned from ``proc.communicate()`` should
             be unicode-decoded from bytestrings (using the specified encoding, which
-            defaults to “{ENCODING}”) to strings before `back_tick(…)` returns.
-            Default is True.
+            falls back to the system default) to strings before the `back_tick(…)`
+            call returns. Default is True.
         ret_err : bool, optional
             If True, the return value is (stdout, stderr). If False, it is stdout.
             In either case `stdout` and `stderr` are strings containing output
@@ -104,7 +92,7 @@ def back_tick(command,  as_str=True,
             Default is None (exception-raising depends on the value of `ret_err`).
         encoding : str, optional
             The name of the encoding to use when decoding the command output per
-            the `as_str` value. Default is “{ENCODING}”.
+            the `as_str` value. Default is the system default (probably UTF-8).
         directory : str / Directory / path-like, optional
             The directory in which to execute the command. Default is None (in
             which case the process working directory, unchanged, will be used).
@@ -113,7 +101,7 @@ def back_tick(command,  as_str=True,
             Default is False.
         timeout : int, optional
             Number of seconds to wait for the executed command to complete before
-            forcibly killing its subprocess. Default is {DEFAULT_TIMEOUT} seconds.
+            forcibly killing its subprocess. Default is sixty (60) seconds.
         
         Returns
         -------
@@ -736,6 +724,21 @@ class Directory(BaseFSName,
             raise FilesystemError(f"mountpoint exists at subdirectory path: {path}")
         return self.directory(path)
     
+    def subdirectories(self, pattern=None, source=None):
+        """ List all subdirectories, as Directory instances.
+            The default is to use the process’ current working directory.
+            
+            Specify an optional “pattern” parameter to filter the list
+            by a particular regex pattern, as applied to directory names.
+        """
+        if not self.exists:
+            return tuple()
+        with os.scandir(self.realpath(source)) as iterscan:
+            return tuple(map(lambda dirname: self.directory(dirname),
+                         filter(re_searcher(pattern),
+                        (direntry.name for direntry in iterscan \
+                                        if direntry.is_dir()))))
+    
     def makedirs(self, subpath=None, mode=0o755):
         """ Creates any parts of the target directory path that don’t
             already exist, á la the `mkdir -p` shell command.
@@ -756,7 +759,38 @@ class Directory(BaseFSName,
             Note that the “followlinks” default here is True, whereas
             the underlying function defaults to False for that argument.
         """
-        return os.walk(self.name, followlinks=followlinks)
+        yield from os.walk(self.name, followlinks=followlinks)
+    
+    def walkback(self, followlinks=True):
+        """ Iterator over reverse-walked directories and files.
+            
+            N.B. Since I had to implement this myself, “followlinks”
+            doesn’t do anything yet. This is because I am lazy and
+            I lack intellectual rigor.
+            
+            The return triple resemples that yielded by “os.walk(…)” –
+            but unlike that function, modifying the directory listing
+            in-situ doesn’t do anything, because think about it.
+        """
+        # Use a boolean predicate to group entries:
+        is_dir_predicate = lambda direntry: direntry.is_dir()
+        directory = self
+        
+        # Recurse upwards until we hit the filesystem root:
+        while True:
+            dirs = []
+            files = []
+            with os.scandir(directory.realpath()) as iterscan:
+                # Q.v. “grouped(…)” in clu.fs.misc supra:
+                for is_dir, group in grouped(iterscan, predicate=is_dir_predicate):
+                    if is_dir:
+                        dirs = [thing.name for thing in group]
+                    else:
+                        files = [thing.name for thing in group]
+                yield directory, dirs, files
+            if directory.name == ROOT_PATH:
+                break
+            directory = directory.parent()
     
     def flatten(self, destination, suffix=None, new_suffix=None):
         """ Copy the entire directory tree, all contents included, to a new
@@ -990,6 +1024,36 @@ class Directory(BaseFSName,
     def __rtruediv__(self, filepath):
         return self.directory(filepath).subdirectory(self)
 
+@export
+def which(binary_name, pathvar=None, pathsep=None):
+    """ Deduces the path corresponding to an executable name,
+        as per the UNIX command `which`. Optionally takes an
+        override for the $PATH environment variable.
+        Always returns a string - an empty one for those
+        executables that cannot be found.
+    """
+    # The original version of this relied on the `find_executable(…)`
+    # function from `distutils.spawn` – it’s been rewritten to use the
+    # CLU internals (which is actually faster, and also betterer).
+    if not pathvar:
+        pathvar = which.pathvar
+    
+    # Allow specification of weird path separators:
+    if not pathsep:
+        pathsep = os.pathsep
+    
+    # The “filter(None, …)” clause removes nonexistant paths, as path
+    # instances evaluated in boolean context have a value that reflects
+    # whether or not they exist:
+    for path in filter(None, (Directory(p) for p in pathvar.split(pathsep))):
+        if binary_name in path:
+            return path.subpath(binary_name)
+    
+    # Empty string indicates failure, bubkiss, nada:
+    return ''
+
+which.pathvar = PATH
+
 @export
 class cd(Directory):
     
