@@ -82,7 +82,7 @@ nopyattrs   = negate(anypyattrs)
 
 # Calling “typeof(…)” on a thing returns either its type, or – if it is
 # a classtype – the thing itself:
-typeof      = lambda thing: nopyattr(thing, 'mro') and type(thing) or thing
+typeof      = lambda thing: (thing is not None and nopyattr(thing, 'mro')) and type(thing) or thing
 
 # Things with a __len__(…) method “have length”:
 haslength   = lambda thing: haspyattr(thing, 'len')
@@ -202,8 +202,8 @@ unwrap      = lambda thing: dunder_or(thing, 'wrapped')
 origin      = lambda thing: typeof(dunder_or(thing, 'origin'))
 rmro        = reverse(mro)
 
-isancestor  = lambda cls, ancestor=object: isclasstype(cls) and (ancestor in mro(cls))
-isorigin    = lambda cls, original=object: isclasstype(cls) and isancestor(origin(cls), typeof(original))
+isancestor  = lambda cls, ancestor=object:   ancestor in mro(cls)
+isorigin    = lambda cls, originator=object: isancestor(origin(cls), ancestor=typeof(originator))
 
 ispublic    = lambda string: not ispyname(string) and not ismifflin(string)
 
@@ -319,14 +319,7 @@ class Partial(partial):
             super(Partial, self).__init__() # type: ignore
         
         # Name the Partial instance, as if it’s a phi-type:
-        qname = or_none(self, '__qualname__')
-        if qname:
-            setattr(self, '__qualname__',
-                    qname.replace(
-                    getattr(self, '__name__'), φ))
-        else:
-            self.__qualname__ = φ
-        self.__name__ = φ
+        self.__name__ = self.__qualname__ = φ
     
     @property
     def predicate(self):
@@ -478,6 +471,10 @@ def noneof(*items):
     """ noneof(*items) → Return the result of “not any(…)” on all non-`None` arguments """
     return negate(any)(item for item in items if item is not None)
 
+# This allows “slots_for(…)”, below, to deal with slots defined with one string, á la:
+# >>> __slots__ = 'string'
+normalize = lambda thing: isnormative(thing) and tuplize(thing) or thing
+
 @cache
 def slots_for(cls):
     """ slots_for(cls) → get the summation of the `__slots__` tuples for a class and its ancestors """
@@ -485,8 +482,8 @@ def slots_for(cls):
     if nopyattrs(cls, 'mro', 'bases'):
         return slots_for(type(cls))
     mro = pyattr(cls, 'mro', 'bases', default=tuplize(object))
-    return tuple(iterchain(
-                 getpyattr(ancestor, 'slots', tuple()) \
+    return tuple(iterchain(normalize(
+                 getpyattr(ancestor, 'slots', tuple())) \
                        for ancestor in reversed(mro)))
 
 # MODULE EXPORTS:
@@ -601,6 +598,7 @@ export(uppers,          name='uppers',          doc="uppers(string) → Sorting
 export(isnotnone,       name='isnotnone',       doc="isnotnone(thing) → boolean predicate, return True if “thing” is not None")
 export(ancestral,       name='ancestral',       doc="ancestral(atx, cls[, default]) → shortcut for “attr_across(atx, *rmro(cls)[, default])”")
 export(ancestral_union, name='ancestral_union', doc="ancestral_union(atx, cls[, default]) → shortcut for “uniquify(iterchain(attr_across(atx, *mro(cls)[, default])))”")
+export(normalize,       name='normalize',       doc="normalize(thing) → tuplizes strings but lets other iterables pass through unchanged")
 
 export(thing_has,       name='thing_has',       doc="thing_has(thing, attribute) → boolean predicate, True if `thing` has “attribute” (in either `__dict__` or `__slots__`)")
 export(class_has,       name='class_has',       doc="class_has(cls, attribute) → boolean predicate, True if `cls` is a class type and has “attribute” (in either `__dict__` or `__slots__`)")
