@@ -135,6 +135,9 @@ def format_environment(environment=None):
     if environment is None:
         environment = os.environ
     
+    if not environment:
+        return
+    
     most = max(len(key) for key in environment.keys()) + 2
     printer = pprint.PrettyPrinter(indent=(most + 6), width=WIDTH)
     wrapper = textwrap.TextWrapper(initial_indent='',
@@ -201,7 +204,7 @@ class Bucket(enum.Enum):
     @property
     def group_title(self):
         return str(self.value)
-    
+
 @export
 class InlineTester(collections.abc.Set,
                    collections.abc.Sequence,
@@ -227,6 +230,10 @@ class InlineTester(collections.abc.Set,
                 def test_two():
                     # ...
                 
+                @inline.runif(something == something_else)
+                def test_conditionally_run():
+                    # ...
+                
                 @inline.diagnostic
                 def apres_testing():
                    # ...
@@ -438,6 +445,7 @@ class InlineTester(collections.abc.Set,
             self.prechecks.insert(0, begin_wrapper)
             self.diagnostics.insert(0, end_wrapper)
             return function
+        
         return decoration
     
     @property
@@ -453,6 +461,24 @@ class InlineTester(collections.abc.Set,
             
             self.fixtures[name] = wrapper = lru_cache(maxsize=16, typed=False)(function)
             return wrapper
+        
+        return decoration
+    
+    def runif(self, boolean):
+        """ Run a test function only if a boolean condition is true. Like so:
+            
+            @inline.runif(consts.TEXTMATE)
+            def test_in_textmate_only():
+                # … insert test code here …
+            
+        """
+        from clu.predicates import none_function
+        
+        def decoration(function):
+            if boolean:
+                return self.__call__(function)
+            return self.__call__(wraps(function)(none_function))
+        
         return decoration
     
     def test(self, exec_count=1, *args, **kwargs):
@@ -542,11 +568,11 @@ class InlineTester(collections.abc.Set,
                   f", {diacount} diagnostic{multiple(diacount)}")
             
             # Body:
-            asterisks('≈')
+            asterisks('∆')
             print(out)
             
             # Footer:
-            asterisks('≠')
+            asterisks('∇')
         
         elif mode == 'json':
             out = json_report(report)
@@ -730,6 +756,11 @@ def test():
         
         assert not temporarydir.exists
     
+    @inline
+    def test_four_show_empty_env():
+        for envline in format_environment(environment={}):
+            print(envline)
+    
     @inline.diagnostic
     def show_environment():
         """ Show environment variables """
